@@ -10,3 +10,7 @@ class AnimalKingdom(DisneyPark):
 
     def getName(self):
         return "Disney's Animal Kingdom"
+   
+    def get_api_id(self):
+        return 'WaltDisneyWorldAnimalKingdom'
+
