@@ -10,3 +10,6 @@ class CaliforniaAdventure(DisneyPark):
 
     def getName(self):
         return "Disney California Adventure"
+    def get_api_id(self):
+        return 'DisneylandResortCaliforniaAdventure'
+
