@@ -10,3 +10,6 @@ class Disneyland(DisneyPark):
 
     def getName(self):
         return "Disneyland"
+    
+    def get_api_id(self):
+        return 'DisneylandResortMagicKingdom'
