@@ -10,3 +10,6 @@ class Epcot(DisneyPark):
 
     def getName(self):
         return "Epcot"
+    
+    def get_api_id(self):
+        return 'WaltDisneyWorldEpcot'
