@@ -10,3 +10,6 @@ class HollywoodStudios(DisneyPark):
 
     def getName(self):
         return "Disney's Hollywood Studios"
+    
+    def get_api_id(self):
+        return 'WaltDisneyWorldHollywoodStudios'
