@@ -10,3 +10,6 @@ class MagicKingdom(DisneyPark):
 
     def getName(self):
         return "Disney's Magic Kingdom"
+    
+    def get_api_id(self):
+        return 'WaltDisneyWorldMagicKingdom'
