@@ -1,7 +1,7 @@
 from pymusement.attraction import Attraction
 class Ride(Attraction):
 
-    _added_keys = ['wait', 'isOpen', 'status', 'single_rider', 'virtual_line']
+    _added_keys = ['wait', 'isOpen', 'status', 'single_rider', 'skipLine']
 
     def __init__(self):
         super(Ride, self).__init__()
@@ -24,14 +24,14 @@ class Ride(Attraction):
             time = int(time)
         self['single_rider'] = time
     
-    def has_virtual_line(self):
-        if self['VirtualLine'] == True:
+    def has_skip_line(self):
+        if self['skipLine'] == True:
             return True
         else:
             return False
         
-    def setVirtualLine(self, status):
-        self['virtual_line'] = status
+    def set_skip_line(self, status):
+        self['skipLine'] = status
     
     def isOpen(self):
         if self['isOpen'] == True:
